@@ -69,7 +69,7 @@ def create_test_suites(filename=None, config=None, _globals=None, options=None):
     if options is None:         #pragma:nocover
         options = Options()
     #
-    # Add categories specified by the PYUTILIB_AUTOTEST_CATEGORIES 
+    # Add categories specified by the PYUTILIB_AUTOTEST_CATEGORIES
     # or PYUTILIB_UNITTEST_CATEGORIES environments
     #
     if options is None or options.categories is None or len(options.categories) == 0:
@@ -162,7 +162,7 @@ def create_test_suite(suite, config, _globals, options):
         ##sname = solver
         test_name = solver+"_"+problem
         #
-        def fn(testcase, suite, name):
+        def fn(testcase, name, suite):
             options = testcase._options[suite,name]
             fn.test_driver.setUp(testcase, options)
             ans = fn.test_driver.run_test(testcase, name, options)
@@ -293,7 +293,7 @@ def run(argv, _globals=None):
         help='Print the test suite categories that can be specified')
     #
     # Parse the argument list and print help info if needed
-    # 
+    #
     _options, args = parser.parse_args(sys.argv)
     if _options.help:
         parser.print_help()
@@ -402,7 +402,7 @@ Examples:
     #
     unittest.main(module=_globals['__name__'])
     cleanup(_globals, suites)
-        
-        
+
+
 def main(_globals=None):
     run(sys.argv, _globals=_globals)
